@@ -2,18 +2,15 @@
 library(shiny)
 library(shinyjqui)
 library(shinydashboard)
+library(shinyWidgets)
 library(shinydashboardPlus)
 library(shinyAce)
 library(styler)
-library(shinyWidgets)
 library(shinyEffects)
 
 # tabs
-source("rightsidebar_tab.R")
-source("header_tab.R")
 source("boxes/close_box.R")
 source("boxes/label_box.R")
-source("boxes/gradient_box.R")
 source("boxes/widget_user_box.R")
 source("boxes/social_box.R")
 source("boxes/flip_box.R")
@@ -36,7 +33,6 @@ source("box_elements/user_post.R")
 source("box_elements/user_messages.R")
 source("box_elements/box_elements_tab.R")
 
-source("extra_elements/rightsidebar_menu.R")
 source("extra_elements/vertical_progress.R")
 source("extra_elements/carousels.R")
 source("extra_elements/extra_elements_tab.R")
\ No newline at end of file
